ENcopyreport: Copies the current contents of a project's report file to...

View source: R/report.r

ENcopyreportR Documentation

Copies the current contents of a project's report file to another file

Description

Copies the current contents of a project's report file to another file

Usage

ENcopyreport(rptFile)

Arguments

rptFile

destination file

Details

This function allows toolkit clients to retrieve the contents of a project's report file while the project is still open.

Value

Returns NULL invisibly; called for side effect

Returns NULL invisibly; called for side effect


epanet2toolkit documentation built on June 3, 2026, 5:06 p.m.