ENdeletelink: Delete a link from the project.
Description
Delete a link from the project.
Usage
ENdeletelink(index, action = "EN_UNCONDITIONAL")
Arguments
- index
the index of the link to be deleted.
- action
The action taken if any control contains the link.
Details
If actionCode is EN_UNCONDITIONAL then the link and all simple and rule-based
controls that contain it are deleted. If set to EN_CONDITIONAL then the link
is not deleted if it appears in any control and error 261 is returned.