ENsetheadcurveindex: Sets index of head curve used by a pump

View source: R/pumps.r

ENsetheadcurveindexR Documentation

Sets index of head curve used by a pump

Description

Sets index of head curve used by a pump

Usage

ENsetheadcurveindex(linkindex, curveindex)

Arguments

linkindex

index of the pump

curveindex

index of head curve to assign

Value

null invisibly


epanet2toolkit documentation built on June 3, 2026, 5:06 p.m.